/* A Bison parser, made by GNU Bison 3.8.2.  */

/* Bison interface for Yacc-like parsers in C

   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2021 Free Software Foundation,
   Inc.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

/* As a special exception, you may create a larger work that contains
   part or all of the Bison parser skeleton and distribute that work
   under terms of your choice, so long as that work isn't itself a
   parser generator using the skeleton or a modified version thereof
   as a parser skeleton.  Alternatively, if you modify or redistribute
   the parser skeleton itself, you may (at your option) remove this
   special exception, which will cause the skeleton and the resulting
   Bison output files to be licensed under the GNU General Public
   License without this special exception.

   This special exception was added by the Free Software Foundation in
   version 2.2 of Bison.  */

/* DO NOT RELY ON FEATURES THAT ARE NOT DOCUMENTED in the manual,
   especially those whose name start with YY_ or yy_.  They are
   private implementation details that can be changed or removed.  */

#ifndef YY_YY_BASICPARSE_TAB_H_INCLUDED
# define YY_YY_BASICPARSE_TAB_H_INCLUDED
/* Debug traces.  */
#ifndef YYDEBUG
# define YYDEBUG 0
#endif
#if YYDEBUG
extern int yydebug;
#endif

/* Token kinds.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
  enum yytokentype
  {
    YYEMPTY = -2,
    YYEOF = 0,                     /* "end of file"  */
    YYerror = 256,                 /* error  */
    YYUNDEF = 257,                 /* "invalid token"  */
    B256ABS = 258,                 /* B256ABS  */
    B256ACOS = 259,                /* B256ACOS  */
    B256ADD1 = 260,                /* B256ADD1  */
    B256ADDEQUAL = 261,            /* B256ADDEQUAL  */
    B256ALERT = 262,               /* B256ALERT  */
    B256AMP = 263,                 /* B256AMP  */
    B256AMPEQUAL = 264,            /* B256AMPEQUAL  */
    B256AND = 265,                 /* B256AND  */
    B256ARC = 266,                 /* B256ARC  */
    B256ARRAYBASE = 267,           /* B256ARRAYBASE  */
    B256ASC = 268,                 /* B256ASC  */
    B256ASIN = 269,                /* B256ASIN  */
    B256ASSIGNED = 270,            /* B256ASSIGNED  */
    B256ATAN = 271,                /* B256ATAN  */
    B256BEGINCASE = 272,           /* B256BEGINCASE  */
    B256BINARYNOT = 273,           /* B256BINARYNOT  */
    B256BINARYOR = 274,            /* B256BINARYOR  */
    B256BITSHIFTL = 275,           /* B256BITSHIFTL  */
    B256BITSHIFTR = 276,           /* B256BITSHIFTR  */
    B256BLACK = 277,               /* B256BLACK  */
    B256BLUE = 278,                /* B256BLUE  */
    B256BOOLEOF = 279,             /* B256BOOLEOF  */
    B256BOOLFALSE = 280,           /* B256BOOLFALSE  */
    B256BOOLTRUE = 281,            /* B256BOOLTRUE  */
    B256CALL = 282,                /* B256CALL  */
    B256CASE = 283,                /* B256CASE  */
    B256CATCH = 284,               /* B256CATCH  */
    B256CEIL = 285,                /* B256CEIL  */
    B256CHANGEDIR = 286,           /* B256CHANGEDIR  */
    B256CHORD = 287,               /* B256CHORD  */
    B256CHR = 288,                 /* B256CHR  */
    B256CIRCLE = 289,              /* B256CIRCLE  */
    B256CLEAR = 290,               /* B256CLEAR  */
    B256CLG = 291,                 /* B256CLG  */
    B256CLICKB = 292,              /* B256CLICKB  */
    B256CLICKCLEAR = 293,          /* B256CLICKCLEAR  */
    B256CLICKX = 294,              /* B256CLICKX  */
    B256CLICKY = 295,              /* B256CLICKY  */
    B256CLOSE = 296,               /* B256CLOSE  */
    B256CLS = 297,                 /* B256CLS  */
    B256CONFIRM = 298,             /* B256CONFIRM  */
    B256CONTINUEDO = 299,          /* B256CONTINUEDO  */
    B256CONTINUEFOR = 300,         /* B256CONTINUEFOR  */
    B256CONTINUEWHILE = 301,       /* B256CONTINUEWHILE  */
    B256COS = 302,                 /* B256COS  */
    B256COUNT = 303,               /* B256COUNT  */
    B256COUNTX = 304,              /* B256COUNTX  */
    B256CURRENTDIR = 305,          /* B256CURRENTDIR  */
    B256CYAN = 306,                /* B256CYAN  */
    B256DARKBLUE = 307,            /* B256DARKBLUE  */
    B256DARKCYAN = 308,            /* B256DARKCYAN  */
    B256DARKGREEN = 309,           /* B256DARKGREEN  */
    B256DARKGREY = 310,            /* B256DARKGREY  */
    B256DARKORANGE = 311,          /* B256DARKORANGE  */
    B256DARKPURPLE = 312,          /* B256DARKPURPLE  */
    B256DARKRED = 313,             /* B256DARKRED  */
    B256DARKYELLOW = 314,          /* B256DARKYELLOW  */
    B256DAY = 315,                 /* B256DAY  */
    B256DBCLOSE = 316,             /* B256DBCLOSE  */
    B256DBCLOSESET = 317,          /* B256DBCLOSESET  */
    B256DBEXECUTE = 318,           /* B256DBEXECUTE  */
    B256DBFLOAT = 319,             /* B256DBFLOAT  */
    B256DBINT = 320,               /* B256DBINT  */
    B256DBNULL = 321,              /* B256DBNULL  */
    B256DBOPEN = 322,              /* B256DBOPEN  */
    B256DBOPENSET = 323,           /* B256DBOPENSET  */
    B256DBROW = 324,               /* B256DBROW  */
    B256DBSTRING = 325,            /* B256DBSTRING  */
    B256DEBUGINFO = 326,           /* B256DEBUGINFO  */
    B256DEGREES = 327,             /* B256DEGREES  */
    B256DIM = 328,                 /* B256DIM  */
    B256DIR = 329,                 /* B256DIR  */
    B256DIVEQUAL = 330,            /* B256DIVEQUAL  */
    B256DO = 331,                  /* B256DO  */
    B256EDITVISIBLE = 332,         /* B256EDITVISIBLE  */
    B256ELLIPSE = 333,             /* B256ELLIPSE  */
    B256ELSE = 334,                /* B256ELSE  */
    B256END = 335,                 /* B256END  */
    B256ENDCASE = 336,             /* B256ENDCASE  */
    B256ENDFUNCTION = 337,         /* B256ENDFUNCTION  */
    B256ENDIF = 338,               /* B256ENDIF  */
    B256ENDSUBROUTINE = 339,       /* B256ENDSUBROUTINE  */
    B256ENDTRY = 340,              /* B256ENDTRY  */
    B256ENDWHILE = 341,            /* B256ENDWHILE  */
    B256ERROR_ARGUMENTCOUNT = 342, /* B256ERROR_ARGUMENTCOUNT  */
    B256ERROR_ARRAYELEMENT = 343,  /* B256ERROR_ARRAYELEMENT  */
    B256ERROR_ARRAYEVEN = 344,     /* B256ERROR_ARRAYEVEN  */
    B256ERROR_ARRAYEXPR = 345,     /* B256ERROR_ARRAYEXPR  */
    B256ERROR_ARRAYINDEX = 346,    /* B256ERROR_ARRAYINDEX  */
    B256ERROR_ARRAYINDEXMISSING = 347, /* B256ERROR_ARRAYINDEXMISSING  */
    B256ERROR_ARRAYLENGTH2D = 348, /* B256ERROR_ARRAYLENGTH2D  */
    B256ERROR_ARRAYNITEMS = 349,   /* B256ERROR_ARRAYNITEMS  */
    B256ERROR_ARRAYSIZELARGE = 350, /* B256ERROR_ARRAYSIZELARGE  */
    B256ERROR_ARRAYSIZESMALL = 351, /* B256ERROR_ARRAYSIZESMALL  */
    B256ERROR_ASINACOSRANGE = 352, /* B256ERROR_ASINACOSRANGE  */
    B256ERROR_BOOLEANCONV = 353,   /* B256ERROR_BOOLEANCONV  */
    B256ERROR_DBCOLNO = 354,       /* B256ERROR_DBCOLNO  */
    B256ERROR_DBCONNNUMBER = 355,  /* B256ERROR_DBCONNNUMBER  */
    B256ERROR_DBNOTOPEN = 356,     /* B256ERROR_DBNOTOPEN  */
    B256ERROR_DBNOTSET = 357,      /* B256ERROR_DBNOTSET  */
    B256ERROR_DBNOTSETROW = 358,   /* B256ERROR_DBNOTSETROW  */
    B256ERROR_DBOPEN = 359,        /* B256ERROR_DBOPEN  */
    B256ERROR_DBQUERY = 360,       /* B256ERROR_DBQUERY  */
    B256ERROR_DBSETNUMBER = 361,   /* B256ERROR_DBSETNUMBER  */
    B256ERROR_DIVZERO = 362,       /* B256ERROR_DIVZERO  */
    B256ERROR_DOWNLOAD = 363,      /* B256ERROR_DOWNLOAD  */
    B256ERROR_ENVELOPEMAX = 364,   /* B256ERROR_ENVELOPEMAX  */
    B256ERROR_ENVELOPEODD = 365,   /* B256ERROR_ENVELOPEODD  */
    B256ERROR_EXPECTEDARRAY = 366, /* B256ERROR_EXPECTEDARRAY  */
    B256ERROR_EXPECTEDSOUND = 367, /* B256ERROR_EXPECTEDSOUND  */
    B256ERROR_FILENOTOPEN = 368,   /* B256ERROR_FILENOTOPEN  */
    B256ERROR_FILENUMBER = 369,    /* B256ERROR_FILENUMBER  */
    B256ERROR_FILEOPEN = 370,      /* B256ERROR_FILEOPEN  */
    B256ERROR_FILEOPERATION = 371, /* B256ERROR_FILEOPERATION  */
    B256ERROR_FILERESET = 372,     /* B256ERROR_FILERESET  */
    B256ERROR_FILEWRITE = 373,     /* B256ERROR_FILEWRITE  */
    B256ERROR_FOLDER = 374,        /* B256ERROR_FOLDER  */
    B256ERROR_FREEDB = 375,        /* B256ERROR_FREEDB  */
    B256ERROR_FREEDBSET = 376,     /* B256ERROR_FREEDBSET  */
    B256ERROR_FREEFILE = 377,      /* B256ERROR_FREEFILE  */
    B256ERROR_FREENET = 378,       /* B256ERROR_FREENET  */
    B256ERROR_HARMONICLIST = 379,  /* B256ERROR_HARMONICLIST  */
    B256ERROR_HARMONICNUMBER = 380, /* B256ERROR_HARMONICNUMBER  */
    B256ERROR_IMAGEFILE = 381,     /* B256ERROR_IMAGEFILE  */
    B256ERROR_IMAGERESOURCE = 382, /* B256ERROR_IMAGERESOURCE  */
    B256ERROR_IMAGESAVETYPE = 383, /* B256ERROR_IMAGESAVETYPE  */
    B256ERROR_IMAGESCALE = 384,    /* B256ERROR_IMAGESCALE  */
    B256ERROR_INFINITY = 385,      /* B256ERROR_INFINITY  */
    B256ERROR_INTEGERRANGE = 386,  /* B256ERROR_INTEGERRANGE  */
    B256ERROR_INVALIDKEYNAME = 387, /* B256ERROR_INVALIDKEYNAME  */
    B256ERROR_INVALIDPROGNAME = 388, /* B256ERROR_INVALIDPROGNAME  */
    B256ERROR_INVALIDRESOURCE = 389, /* B256ERROR_INVALIDRESOURCE  */
    B256ERROR_LOGRANGE = 390,      /* B256ERROR_LOGRANGE  */
    B256ERROR_LONGRANGE = 391,     /* B256ERROR_LONGRANGE  */
    B256ERROR_MAXRECURSE = 392,    /* B256ERROR_MAXRECURSE  */
    B256ERROR_NETACCEPT = 393,     /* B256ERROR_NETACCEPT  */
    B256ERROR_NETBIND = 394,       /* B256ERROR_NETBIND  */
    B256ERROR_NETCONN = 395,       /* B256ERROR_NETCONN  */
    B256ERROR_NETHOST = 396,       /* B256ERROR_NETHOST  */
    B256ERROR_NETNONE = 397,       /* B256ERROR_NETNONE  */
    B256ERROR_NETREAD = 398,       /* B256ERROR_NETREAD  */
    B256ERROR_NETSOCK = 399,       /* B256ERROR_NETSOCK  */
    B256ERROR_NETSOCKNUMBER = 400, /* B256ERROR_NETSOCKNUMBER  */
    B256ERROR_NETSOCKOPT = 401,    /* B256ERROR_NETSOCKOPT  */
    B256ERROR_NETWRITE = 402,      /* B256ERROR_NETWRITE  */
    B256ERROR_NEXTNOFOR = 403,     /* B256ERROR_NEXTNOFOR  */
    B256ERROR_NONE = 404,          /* B256ERROR_NONE  */
    B256ERROR_NOSUCHFUNCTION = 405, /* B256ERROR_NOSUCHFUNCTION  */
    B256ERROR_NOSUCHLABEL = 406,   /* B256ERROR_NOSUCHLABEL  */
    B256ERROR_NOSUCHSUBROUTINE = 407, /* B256ERROR_NOSUCHSUBROUTINE  */
    B256ERROR_NOTARRAY = 408,      /* B256ERROR_NOTARRAY  */
    B256ERROR_NOTIMPLEMENTED = 409, /* B256ERROR_NOTIMPLEMENTED  */
    B256ERROR_NUMBERCONV = 410,    /* B256ERROR_NUMBERCONV  */
    B256ERROR_NUMBEREXPR = 411,    /* B256ERROR_NUMBEREXPR  */
    B256ERROR_ONEDIMENSIONAL = 412, /* B256ERROR_ONEDIMENSIONAL  */
    B256ERROR_ONERRORSUB = 413,    /* B256ERROR_ONERRORSUB  */
    B256ERROR_PENWIDTH = 414,      /* B256ERROR_PENWIDTH  */
    B256ERROR_PERMISSION = 415,    /* B256ERROR_PERMISSION  */
    B256ERROR_POLYPOINTS = 416,    /* B256ERROR_POLYPOINTS  */
    B256ERROR_PRINTERNOTOFF = 417, /* B256ERROR_PRINTERNOTOFF  */
    B256ERROR_PRINTERNOTON = 418,  /* B256ERROR_PRINTERNOTON  */
    B256ERROR_PRINTEROPEN = 419,   /* B256ERROR_PRINTEROPEN  */
    B256ERROR_RADIX = 420,         /* B256ERROR_RADIX  */
    B256ERROR_RADIXSTRING = 421,   /* B256ERROR_RADIXSTRING  */
    B256ERROR_REFNOTASSIGNED = 422, /* B256ERROR_REFNOTASSIGNED  */
    B256ERROR_RGB = 423,           /* B256ERROR_RGB  */
    B256ERROR_SERIALPARAMETER = 424, /* B256ERROR_SERIALPARAMETER  */
    B256ERROR_SETTINGMAXKEYS = 425, /* B256ERROR_SETTINGMAXKEYS  */
    B256ERROR_SETTINGMAXLEN = 426, /* B256ERROR_SETTINGMAXLEN  */
    B256ERROR_SETTINGSGETACCESS = 427, /* B256ERROR_SETTINGSGETACCESS  */
    B256ERROR_SETTINGSSETACCESS = 428, /* B256ERROR_SETTINGSSETACCESS  */
    B256ERROR_SLICESIZE = 429,     /* B256ERROR_SLICESIZE  */
    B256ERROR_SOUNDERROR = 430,    /* B256ERROR_SOUNDERROR  */
    B256ERROR_SOUNDFILE = 431,     /* B256ERROR_SOUNDFILE  */
    B256ERROR_SOUNDFILEFORMAT = 432, /* B256ERROR_SOUNDFILEFORMAT  */
    B256ERROR_SOUNDLENGTH = 433,   /* B256ERROR_SOUNDLENGTH  */
    B256ERROR_SOUNDNOTSEEKABLE = 434, /* B256ERROR_SOUNDNOTSEEKABLE  */
    B256ERROR_SOUNDRESOURCE = 435, /* B256ERROR_SOUNDRESOURCE  */
    B256ERROR_SPRITENA = 436,      /* B256ERROR_SPRITENA  */
    B256ERROR_SPRITENUMBER = 437,  /* B256ERROR_SPRITENUMBER  */
    B256ERROR_SPRITESLICE = 438,   /* B256ERROR_SPRITESLICE  */
    B256ERROR_SQRRANGE = 439,      /* B256ERROR_SQRRANGE  */
    B256ERROR_STACKUNDERFLOW = 440, /* B256ERROR_STACKUNDERFLOW  */
    B256ERROR_STRING2NOTE = 441,   /* B256ERROR_STRING2NOTE  */
    B256ERROR_STRINGCONV = 442,    /* B256ERROR_STRINGCONV  */
    B256ERROR_STRINGEXPR = 443,    /* B256ERROR_STRINGEXPR  */
    B256ERROR_STRINGMAXLEN = 444,  /* B256ERROR_STRINGMAXLEN  */
    B256ERROR_STRSTART = 445,      /* B256ERROR_STRSTART  */
    B256ERROR_TOOMANYSOUNDS = 446, /* B256ERROR_TOOMANYSOUNDS  */
    B256ERROR_UNEXPECTEDRETURN = 447, /* B256ERROR_UNEXPECTEDRETURN  */
    B256ERROR_UNSERIALIZEFORMAT = 448, /* B256ERROR_UNSERIALIZEFORMAT  */
    B256ERROR_VARCIRCULAR = 449,   /* B256ERROR_VARCIRCULAR  */
    B256ERROR_VARNOTASSIGNED = 450, /* B256ERROR_VARNOTASSIGNED  */
    B256ERROR_VARNULL = 451,       /* B256ERROR_VARNULL  */
    B256ERROR_WAVEFORMLOGICAL = 452, /* B256ERROR_WAVEFORMLOGICAL  */
    B256ERROR_WAVOBSOLETE = 453,   /* B256ERROR_WAVOBSOLETE  */
    B256EXISTS = 454,              /* B256EXISTS  */
    B256EXITDO = 455,              /* B256EXITDO  */
    B256EXITFOR = 456,             /* B256EXITFOR  */
    B256EXITWHILE = 457,           /* B256EXITWHILE  */
    B256EXP = 458,                 /* B256EXP  */
    B256EXPLODE = 459,             /* B256EXPLODE  */
    B256EXPLODEX = 460,            /* B256EXPLODEX  */
    B256FASTGRAPHICS = 461,        /* B256FASTGRAPHICS  */
    B256FILL = 462,                /* B256FILL  */
    B256FLOOR = 463,               /* B256FLOOR  */
    B256FONT = 464,                /* B256FONT  */
    B256FOR = 465,                 /* B256FOR  */
    B256FOREACH = 466,             /* B256FOREACH  */
    B256FREEDB = 467,              /* B256FREEDB  */
    B256FREEDBSET = 468,           /* B256FREEDBSET  */
    B256FREEFILE = 469,            /* B256FREEFILE  */
    B256FREENET = 470,             /* B256FREENET  */
    B256FROMBINARY = 471,          /* B256FROMBINARY  */
    B256FROMHEX = 472,             /* B256FROMHEX  */
    B256FROMOCTAL = 473,           /* B256FROMOCTAL  */
    B256FROMRADIX = 474,           /* B256FROMRADIX  */
    B256FUNCTION = 475,            /* B256FUNCTION  */
    B256GETARRAYBASE = 476,        /* B256GETARRAYBASE  */
    B256GETBRUSHCOLOR = 477,       /* B256GETBRUSHCOLOR  */
    B256GETCLIPBOARDIMAGE = 478,   /* B256GETCLIPBOARDIMAGE  */
    B256GETCLIPBOARDSTRING = 479,  /* B256GETCLIPBOARDSTRING  */
    B256GETCOLOR = 480,            /* B256GETCOLOR  */
    B256GETPENWIDTH = 481,         /* B256GETPENWIDTH  */
    B256GETSETTING = 482,          /* B256GETSETTING  */
    B256GETSLICE = 483,            /* B256GETSLICE  */
    B256GLOBAL = 484,              /* B256GLOBAL  */
    B256GOSUB = 485,               /* B256GOSUB  */
    B256GOTO = 486,                /* B256GOTO  */
    B256GRAPHHEIGHT = 487,         /* B256GRAPHHEIGHT  */
    B256GRAPHSIZE = 488,           /* B256GRAPHSIZE  */
    B256GRAPHVISIBLE = 489,        /* B256GRAPHVISIBLE  */
    B256GRAPHTOOLBARVISIBLE = 490, /* B256GRAPHTOOLBARVISIBLE  */
    B256GRAPHWIDTH = 491,          /* B256GRAPHWIDTH  */
    B256GREEN = 492,               /* B256GREEN  */
    B256GREY = 493,                /* B256GREY  */
    B256GTE = 494,                 /* B256GTE  */
    B256HOUR = 495,                /* B256HOUR  */
    B256IF = 496,                  /* B256IF  */
    B256IN = 497,                  /* B256IN  */
    B256IMAGEAUTOCROP = 498,       /* B256IMAGEAUTOCROP  */
    B256IMAGECENTERED = 499,       /* B256IMAGECENTERED  */
    B256IMAGECOPY = 500,           /* B256IMAGECOPY  */
    B256IMAGECROP = 501,           /* B256IMAGECROP  */
    B256IMAGEDRAW = 502,           /* B256IMAGEDRAW  */
    B256IMAGEFLIP = 503,           /* B256IMAGEFLIP  */
    B256IMAGEHEIGHT = 504,         /* B256IMAGEHEIGHT  */
    B256IMAGELOAD = 505,           /* B256IMAGELOAD  */
    B256IMAGENEW = 506,            /* B256IMAGENEW  */
    B256IMAGEPIXEL = 507,          /* B256IMAGEPIXEL  */
    B256IMAGERESIZE = 508,         /* B256IMAGERESIZE  */
    B256IMAGEROTATE = 509,         /* B256IMAGEROTATE  */
    B256IMAGESETPIXEL = 510,       /* B256IMAGESETPIXEL  */
    B256IMAGESMOOTH = 511,         /* B256IMAGESMOOTH  */
    B256IMAGETRANSFORMED = 512,    /* B256IMAGETRANSFORMED  */
    B256IMAGETYPE_BMP = 513,       /* B256IMAGETYPE_BMP  */
    B256IMAGETYPE_JPG = 514,       /* B256IMAGETYPE_JPG  */
    B256IMAGETYPE_PNG = 515,       /* B256IMAGETYPE_PNG  */
    B256IMAGEWIDTH = 516,          /* B256IMAGEWIDTH  */
    B256IMGLOAD = 517,             /* B256IMGLOAD  */
    B256IMGSAVE = 518,             /* B256IMGSAVE  */
    B256IMPLODE = 519,             /* B256IMPLODE  */
    B256INPUT = 520,               /* B256INPUT  */
    B256INPUTFLOAT = 521,          /* B256INPUTFLOAT  */
    B256INPUTINT = 522,            /* B256INPUTINT  */
    B256INPUTSTRING = 523,         /* B256INPUTSTRING  */
    B256INSTR = 524,               /* B256INSTR  */
    B256INSTRX = 525,              /* B256INSTRX  */
    B256INTDIV = 526,              /* B256INTDIV  */
    B256ISNUMERIC = 527,           /* B256ISNUMERIC  */
    B256KEY = 528,                 /* B256KEY  */
    B256KEYPRESSED = 529,          /* B256KEYPRESSED  */
    B256KILL = 530,                /* B256KILL  */
    B256LASTERROR = 531,           /* B256LASTERROR  */
    B256LASTERROREXTRA = 532,      /* B256LASTERROREXTRA  */
    B256LASTERRORLINE = 533,       /* B256LASTERRORLINE  */
    B256LASTERRORMESSAGE = 534,    /* B256LASTERRORMESSAGE  */
    B256LEFT = 535,                /* B256LEFT  */
    B256LENGTH = 536,              /* B256LENGTH  */
    B256LET = 537,                 /* B256LET  */
    B256LINE = 538,                /* B256LINE  */
    B256LJUST = 539,               /* B256LJUST  */
    B256LOG = 540,                 /* B256LOG  */
    B256LOGTEN = 541,              /* B256LOGTEN  */
    B256LOWER = 542,               /* B256LOWER  */
    B256LTE = 543,                 /* B256LTE  */
    B256LTRIM = 544,               /* B256LTRIM  */
    B256MAINTOOLBARVISIBLE = 545,  /* B256MAINTOOLBARVISIBLE  */
    B256MAP = 546,                 /* B256MAP  */
    B256MD5 = 547,                 /* B256MD5  */
    B256MID = 548,                 /* B256MID  */
    B256MIDX = 549,                /* B256MIDX  */
    B256MINUTE = 550,              /* B256MINUTE  */
    B256MOD = 551,                 /* B256MOD  */
    B256MKDIR = 552,               /* B256MKDIR  */
    B256MONTH = 553,               /* B256MONTH  */
    B256MOUSEB = 554,              /* B256MOUSEB  */
    B256MOUSEBUTTON_CENTER = 555,  /* B256MOUSEBUTTON_CENTER  */
    B256MOUSEBUTTON_DOUBLECLICK = 556, /* B256MOUSEBUTTON_DOUBLECLICK  */
    B256MOUSEBUTTON_LEFT = 557,    /* B256MOUSEBUTTON_LEFT  */
    B256MOUSEBUTTON_NONE = 558,    /* B256MOUSEBUTTON_NONE  */
    B256MOUSEBUTTON_RIGHT = 559,   /* B256MOUSEBUTTON_RIGHT  */
    B256MOUSEX = 560,              /* B256MOUSEX  */
    B256MOUSEY = 561,              /* B256MOUSEY  */
    B256MSEC = 562,                /* B256MSEC  */
    B256MULEQUAL = 563,            /* B256MULEQUAL  */
    B256NE = 564,                  /* B256NE  */
    B256NETADDRESS = 565,          /* B256NETADDRESS  */
    B256NETCLOSE = 566,            /* B256NETCLOSE  */
    B256NETCONNECT = 567,          /* B256NETCONNECT  */
    B256NETDATA = 568,             /* B256NETDATA  */
    B256NETLISTEN = 569,           /* B256NETLISTEN  */
    B256NETREAD = 570,             /* B256NETREAD  */
    B256NETWRITE = 571,            /* B256NETWRITE  */
    B256NEXT = 572,                /* B256NEXT  */
    B256NOT = 573,                 /* B256NOT  */
    B256OFFERROR = 574,            /* B256OFFERROR  */
    B256ONERROR = 575,             /* B256ONERROR  */
    B256ONSTOP = 576,              /* B256ONSTOP  */
    B256OPEN = 577,                /* B256OPEN  */
    B256OPENB = 578,               /* B256OPENB  */
    B256OPENFILEDIALOG = 579,      /* B256OPENFILEDIALOG  */
    B256OPENSERIAL = 580,          /* B256OPENSERIAL  */
    B256OR = 581,                  /* B256OR  */
    B256ORANGE = 582,              /* B256ORANGE  */
    B256OSTYPE = 583,              /* B256OSTYPE  */
    B256OSTYPE_ANDROID = 584,      /* B256OSTYPE_ANDROID  */
    B256OSTYPE_LINUX = 585,        /* B256OSTYPE_LINUX  */
    B256OSTYPE_MACINTOSH = 586,    /* B256OSTYPE_MACINTOSH  */
    B256OSTYPE_WINDOWS = 587,      /* B256OSTYPE_WINDOWS  */
    B256OUTPUTVISIBLE = 588,       /* B256OUTPUTVISIBLE  */
    B256OUTPUTTOOLBARVISIBLE = 589, /* B256OUTPUTTOOLBARVISIBLE  */
    B256PAUSE = 590,               /* B256PAUSE  */
    B256PENWIDTH = 591,            /* B256PENWIDTH  */
    B256PI = 592,                  /* B256PI  */
    B256PIE = 593,                 /* B256PIE  */
    B256PIXEL = 594,               /* B256PIXEL  */
    B256PLOT = 595,                /* B256PLOT  */
    B256POLY = 596,                /* B256POLY  */
    B256PORTIN = 597,              /* B256PORTIN  */
    B256PORTOUT = 598,             /* B256PORTOUT  */
    B256PRINT = 599,               /* B256PRINT  */
    B256PRINTAT = 600,             /* B256PRINTAT  */
    B256PRINTERCANCEL = 601,       /* B256PRINTERCANCEL  */
    B256PRINTEROFF = 602,          /* B256PRINTEROFF  */
    B256PRINTERON = 603,           /* B256PRINTERON  */
    B256PRINTERPAGE = 604,         /* B256PRINTERPAGE  */
    B256PROMPT = 605,              /* B256PROMPT  */
    B256PURPLE = 606,              /* B256PURPLE  */
    B256PUTSLICE = 607,            /* B256PUTSLICE  */
    B256RADIANS = 608,             /* B256RADIANS  */
    B256RAND = 609,                /* B256RAND  */
    B256READ = 610,                /* B256READ  */
    B256READBYTE = 611,            /* B256READBYTE  */
    B256READLINE = 612,            /* B256READLINE  */
    B256RECT = 613,                /* B256RECT  */
    B256RED = 614,                 /* B256RED  */
    B256REDIM = 615,               /* B256REDIM  */
    B256REF = 616,                 /* B256REF  */
    B256REFRESH = 617,             /* B256REFRESH  */
    B256REGEXMINIMAL = 618,        /* B256REGEXMINIMAL  */
    B256REM = 619,                 /* B256REM  */
    B256REPLACE = 620,             /* B256REPLACE  */
    B256REPLACEX = 621,            /* B256REPLACEX  */
    B256SAVEFILEDIALOG = 622,      /* B256SAVEFILEDIALOG  */
    B256RESET = 623,               /* B256RESET  */
    B256RETURN = 624,              /* B256RETURN  */
    B256RGB = 625,                 /* B256RGB  */
    B256RIGHT = 626,               /* B256RIGHT  */
    B256RJUST = 627,               /* B256RJUST  */
    B256RMDIR = 628,               /* B256RMDIR  */
    B256ROUND = 629,               /* B256ROUND  */
    B256RTRIM = 630,               /* B256RTRIM  */
    B256SAY = 631,                 /* B256SAY  */
    B256SECOND = 632,              /* B256SECOND  */
    B256SEED = 633,                /* B256SEED  */
    B256SEEK = 634,                /* B256SEEK  */
    B256SEMICOLON = 635,           /* B256SEMICOLON  */
    B256SEMICOLONEQUAL = 636,      /* B256SEMICOLONEQUAL  */
    B256SERIALIZE = 637,           /* B256SERIALIZE  */
    B256SETCLIPBOARDIMAGE = 638,   /* B256SETCLIPBOARDIMAGE  */
    B256SETCLIPBOARDSTRING = 639,  /* B256SETCLIPBOARDSTRING  */
    B256SETCOLOR = 640,            /* B256SETCOLOR  */
    B256SETGRAPH = 641,            /* B256SETGRAPH  */
    B256SETSETTING = 642,          /* B256SETSETTING  */
    B256SIN = 643,                 /* B256SIN  */
    B256SIZE = 644,                /* B256SIZE  */
    B256SLICE_ALL = 645,           /* B256SLICE_ALL  */
    B256SLICE_PAINT = 646,         /* B256SLICE_PAINT  */
    B256SLICE_SPRITE = 647,        /* B256SLICE_SPRITE  */
    B256SOUND = 648,               /* B256SOUND  */
    B256SOUNDENVELOPE = 649,       /* B256SOUNDENVELOPE  */
    B256SOUNDFADE = 650,           /* B256SOUNDFADE  */
    B256SOUNDHARMONICS = 651,      /* B256SOUNDHARMONICS  */
    B256SOUNDID = 652,             /* B256SOUNDID  */
    B256SOUNDLENGTH = 653,         /* B256SOUNDLENGTH  */
    B256SOUNDLOAD = 654,           /* B256SOUNDLOAD  */
    B256SOUNDLOADRAW = 655,        /* B256SOUNDLOADRAW  */
    B256SOUNDLOOP = 656,           /* B256SOUNDLOOP  */
    B256SOUNDPAUSE = 657,          /* B256SOUNDPAUSE  */
    B256SOUNDPLAY = 658,           /* B256SOUNDPLAY  */
    B256SOUNDPLAYER = 659,         /* B256SOUNDPLAYER  */
    B256SOUNDPLAYEROFF = 660,      /* B256SOUNDPLAYEROFF  */
    B256SOUNDPOSITION = 661,       /* B256SOUNDPOSITION  */
    B256SOUNDSAMPLERATE = 662,     /* B256SOUNDSAMPLERATE  */
    B256SOUNDSEEK = 663,           /* B256SOUNDSEEK  */
    B256SOUNDSTATE = 664,          /* B256SOUNDSTATE  */
    B256SOUNDSTOP = 665,           /* B256SOUNDSTOP  */
    B256SOUNDSYSTEM = 666,         /* B256SOUNDSYSTEM  */
    B256SOUNDVOLUME = 667,         /* B256SOUNDVOLUME  */
    B256SOUNDWAIT = 668,           /* B256SOUNDWAIT  */
    B256SOUNDWAVEFORM = 669,       /* B256SOUNDWAVEFORM  */
    B256SPRITECOLLIDE = 670,       /* B256SPRITECOLLIDE  */
    B256SPRITEDIM = 671,           /* B256SPRITEDIM  */
    B256SPRITEH = 672,             /* B256SPRITEH  */
    B256SPRITEHIDE = 673,          /* B256SPRITEHIDE  */
    B256SPRITELOAD = 674,          /* B256SPRITELOAD  */
    B256SPRITEMOVE = 675,          /* B256SPRITEMOVE  */
    B256SPRITEO = 676,             /* B256SPRITEO  */
    B256SPRITEPLACE = 677,         /* B256SPRITEPLACE  */
    B256SPRITEPOLY = 678,          /* B256SPRITEPOLY  */
    B256SPRITER = 679,             /* B256SPRITER  */
    B256SPRITES = 680,             /* B256SPRITES  */
    B256SPRITESHOW = 681,          /* B256SPRITESHOW  */
    B256SPRITESLICE = 682,         /* B256SPRITESLICE  */
    B256SPRITETEXT = 683,          /* B256SPRITETEXT  */
    B256SPRITEV = 684,             /* B256SPRITEV  */
    B256SPRITEW = 685,             /* B256SPRITEW  */
    B256SPRITEX = 686,             /* B256SPRITEX  */
    B256SPRITEY = 687,             /* B256SPRITEY  */
    B256SQR = 688,                 /* B256SQR  */
    B256STAMP = 689,               /* B256STAMP  */
    B256STEP = 690,                /* B256STEP  */
    B256SUB1 = 691,                /* B256SUB1  */
    B256SUBEQUAL = 692,            /* B256SUBEQUAL  */
    B256SUBROUTINE = 693,          /* B256SUBROUTINE  */
    B256SYSTEM = 694,              /* B256SYSTEM  */
    B256TAN = 695,                 /* B256TAN  */
    B256TEXT = 696,                /* B256TEXT  */
    B256TEXTHEIGHT = 697,          /* B256TEXTHEIGHT  */
    B256TEXTWIDTH = 698,           /* B256TEXTWIDTH  */
    B256THEN = 699,                /* B256THEN  */
    B256THROWERROR = 700,          /* B256THROWERROR  */
    B256TO = 701,                  /* B256TO  */
    B256TOBINARY = 702,            /* B256TOBINARY  */
    B256TOFLOAT = 703,             /* B256TOFLOAT  */
    B256TOHEX = 704,               /* B256TOHEX  */
    B256TOINT = 705,               /* B256TOINT  */
    B256TOOCTAL = 706,             /* B256TOOCTAL  */
    B256TORADIX = 707,             /* B256TORADIX  */
    B256TOSTRING = 708,            /* B256TOSTRING  */
    B256TRIM = 709,                /* B256TRIM  */
    B256TRY = 710,                 /* B256TRY  */
    B256TYPEOF = 711,              /* B256TYPEOF  */
    B256TYPE_ARRAY = 712,          /* B256TYPE_ARRAY  */
    B256TYPE_FLOAT = 713,          /* B256TYPE_FLOAT  */
    B256TYPE_INT = 714,            /* B256TYPE_INT  */
    B256TYPE_MAP = 715,            /* B256TYPE_MAP  */
    B256TYPE_REF = 716,            /* B256TYPE_REF  */
    B256TYPE_STRING = 717,         /* B256TYPE_STRING  */
    B256TYPE_UNASSIGNED = 718,     /* B256TYPE_UNASSIGNED  */
    B256UNASSIGN = 719,            /* B256UNASSIGN  */
    B256UNLOAD = 720,              /* B256UNLOAD  */
    B256UNSERIALIZE = 721,         /* B256UNSERIALIZE  */
    B256UNTIL = 722,               /* B256UNTIL  */
    B256UPPER = 723,               /* B256UPPER  */
    B256VARIABLEWATCH = 724,       /* B256VARIABLEWATCH  */
    B256VERSION = 725,             /* B256VERSION  */
    B256VOLUME = 726,              /* B256VOLUME  */
    B256WARNING_ARRAYELEMENT = 727, /* B256WARNING_ARRAYELEMENT  */
    B256WARNING_BOOLEANCONV = 728, /* B256WARNING_BOOLEANCONV  */
    B256WARNING_INTEGERRANGE = 729, /* B256WARNING_INTEGERRANGE  */
    B256WARNING_LONGRANGE = 730,   /* B256WARNING_LONGRANGE  */
    B256WARNING_NUMBERCONV = 731,  /* B256WARNING_NUMBERCONV  */
    B256WARNING_REFNOTASSIGNED = 732, /* B256WARNING_REFNOTASSIGNED  */
    B256WARNING_SOUNDERROR = 733,  /* B256WARNING_SOUNDERROR  */
    B256WARNING_SOUNDFILEFORMAT = 734, /* B256WARNING_SOUNDFILEFORMAT  */
    B256WARNING_SOUNDLENGTH = 735, /* B256WARNING_SOUNDLENGTH  */
    B256WARNING_SOUNDNOTSEEKABLE = 736, /* B256WARNING_SOUNDNOTSEEKABLE  */
    B256WARNING_START = 737,       /* B256WARNING_START  */
    B256WARNING_STRING2NOTE = 738, /* B256WARNING_STRING2NOTE  */
    B256WARNING_STRINGCONV = 739,  /* B256WARNING_STRINGCONV  */
    B256WARNING_VARNOTASSIGNED = 740, /* B256WARNING_VARNOTASSIGNED  */
    B256WARNING_WAVOBSOLETE = 741, /* B256WARNING_WAVOBSOLETE  */
    B256WAVLENGTH = 742,           /* B256WAVLENGTH  */
    B256WAVPAUSE = 743,            /* B256WAVPAUSE  */
    B256WAVPLAY = 744,             /* B256WAVPLAY  */
    B256WAVPOS = 745,              /* B256WAVPOS  */
    B256WAVSEEK = 746,             /* B256WAVSEEK  */
    B256WAVSTATE = 747,            /* B256WAVSTATE  */
    B256WAVSTOP = 748,             /* B256WAVSTOP  */
    B256WAVWAIT = 749,             /* B256WAVWAIT  */
    B256WHILE = 750,               /* B256WHILE  */
    B256WHITE = 751,               /* B256WHITE  */
    B256WRITE = 752,               /* B256WRITE  */
    B256WRITEBYTE = 753,           /* B256WRITEBYTE  */
    B256WRITELINE = 754,           /* B256WRITELINE  */
    B256XOR = 755,                 /* B256XOR  */
    B256YEAR = 756,                /* B256YEAR  */
    B256YELLOW = 757,              /* B256YELLOW  */
    B256ZFILL = 758,               /* B256ZFILL  */
    B256INTEGER = 759,             /* B256INTEGER  */
    B256FLOAT = 760,               /* B256FLOAT  */
    B256STRING = 761,              /* B256STRING  */
    B256HEXCONST = 762,            /* B256HEXCONST  */
    B256BINCONST = 763,            /* B256BINCONST  */
    B256OCTCONST = 764,            /* B256OCTCONST  */
    B256VARIABLE = 765,            /* B256VARIABLE  */
    B256LABEL = 766,               /* B256LABEL  */
    B256UNARY = 767                /* B256UNARY  */
  };
  typedef enum yytokentype yytoken_kind_t;
#endif

/* Value type.  */
#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
union anytype
{

	int number;
	double floatnum;
	char *string;


};
typedef union anytype YYSTYPE;
# define YYSTYPE_IS_TRIVIAL 1
# define YYSTYPE_IS_DECLARED 1
#endif


extern YYSTYPE yylval;


int yyparse (void);


#endif /* !YY_YY_BASICPARSE_TAB_H_INCLUDED  */
