/****************************************************************************
** Meta object code from reading C++ file 'RunController.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../RunController.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'RunController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RunController_t {
    QByteArrayData data[49];
    char stringdata0[696];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RunController_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RunController_t qt_meta_stringdata_RunController = {
    {
QT_MOC_LITERAL(0, 0, 13), // "RunController"
QT_MOC_LITERAL(1, 14, 9), // "runHalted"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 10), // "speakWords"
QT_MOC_LITERAL(4, 36, 13), // "executeSystem"
QT_MOC_LITERAL(5, 50, 12), // "inputEntered"
QT_MOC_LITERAL(6, 63, 4), // "text"
QT_MOC_LITERAL(7, 68, 11), // "outputReady"
QT_MOC_LITERAL(8, 80, 11), // "outputError"
QT_MOC_LITERAL(9, 92, 11), // "outputClear"
QT_MOC_LITERAL(10, 104, 12), // "outputTextAt"
QT_MOC_LITERAL(11, 117, 12), // "goutputReady"
QT_MOC_LITERAL(12, 130, 17), // "resizeGraphWindow"
QT_MOC_LITERAL(13, 148, 10), // "startDebug"
QT_MOC_LITERAL(14, 159, 13), // "debugNextStep"
QT_MOC_LITERAL(15, 173, 8), // "startRun"
QT_MOC_LITERAL(16, 182, 7), // "stopRun"
QT_MOC_LITERAL(17, 190, 16), // "stopRunFinalized"
QT_MOC_LITERAL(18, 207, 2), // "ok"
QT_MOC_LITERAL(19, 210, 11), // "stepThrough"
QT_MOC_LITERAL(20, 222, 14), // "stepBreakPoint"
QT_MOC_LITERAL(21, 237, 23), // "showOnlineDocumentation"
QT_MOC_LITERAL(22, 261, 30), // "showOnlineContextDocumentation"
QT_MOC_LITERAL(23, 292, 15), // "showPreferences"
QT_MOC_LITERAL(24, 308, 11), // "showReplace"
QT_MOC_LITERAL(25, 320, 8), // "showFind"
QT_MOC_LITERAL(26, 329, 9), // "findAgain"
QT_MOC_LITERAL(27, 339, 18), // "mainWindowsVisible"
QT_MOC_LITERAL(28, 358, 11), // "dialogAlert"
QT_MOC_LITERAL(29, 370, 13), // "dialogConfirm"
QT_MOC_LITERAL(30, 384, 12), // "dialogPrompt"
QT_MOC_LITERAL(31, 397, 20), // "dialogAllowPortInOut"
QT_MOC_LITERAL(32, 418, 17), // "dialogAllowSystem"
QT_MOC_LITERAL(33, 436, 20), // "dialogOpenFileDialog"
QT_MOC_LITERAL(34, 457, 20), // "dialogSaveFileDialog"
QT_MOC_LITERAL(35, 478, 9), // "playSound"
QT_MOC_LITERAL(36, 488, 33), // "std::vector<std::vector<doubl..."
QT_MOC_LITERAL(37, 522, 18), // "loadSoundFromArray"
QT_MOC_LITERAL(38, 541, 11), // "QByteArray*"
QT_MOC_LITERAL(39, 553, 9), // "soundStop"
QT_MOC_LITERAL(40, 563, 9), // "soundPlay"
QT_MOC_LITERAL(41, 573, 9), // "soundFade"
QT_MOC_LITERAL(42, 583, 11), // "soundVolume"
QT_MOC_LITERAL(43, 595, 14), // "soundPlayerOff"
QT_MOC_LITERAL(44, 610, 11), // "soundSystem"
QT_MOC_LITERAL(45, 622, 17), // "getClipboardImage"
QT_MOC_LITERAL(46, 640, 18), // "getClipboardString"
QT_MOC_LITERAL(47, 659, 17), // "setClipboardImage"
QT_MOC_LITERAL(48, 677, 18) // "setClipboardString"

    },
    "RunController\0runHalted\0\0speakWords\0"
    "executeSystem\0inputEntered\0text\0"
    "outputReady\0outputError\0outputClear\0"
    "outputTextAt\0goutputReady\0resizeGraphWindow\0"
    "startDebug\0debugNextStep\0startRun\0"
    "stopRun\0stopRunFinalized\0ok\0stepThrough\0"
    "stepBreakPoint\0showOnlineDocumentation\0"
    "showOnlineContextDocumentation\0"
    "showPreferences\0showReplace\0showFind\0"
    "findAgain\0mainWindowsVisible\0dialogAlert\0"
    "dialogConfirm\0dialogPrompt\0"
    "dialogAllowPortInOut\0dialogAllowSystem\0"
    "dialogOpenFileDialog\0dialogSaveFileDialog\0"
    "playSound\0std::vector<std::vector<double> >\0"
    "loadSoundFromArray\0QByteArray*\0soundStop\0"
    "soundPlay\0soundFade\0soundVolume\0"
    "soundPlayerOff\0soundSystem\0getClipboardImage\0"
    "getClipboardString\0setClipboardImage\0"
    "setClipboardString"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RunController[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  234,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    1,  235,    2, 0x0a /* Public */,
       4,    1,  238,    2, 0x0a /* Public */,
       5,    1,  241,    2, 0x0a /* Public */,
       7,    1,  244,    2, 0x0a /* Public */,
       8,    1,  247,    2, 0x0a /* Public */,
       9,    0,  250,    2, 0x0a /* Public */,
      10,    3,  251,    2, 0x0a /* Public */,
      11,    0,  258,    2, 0x0a /* Public */,
      12,    3,  259,    2, 0x0a /* Public */,
      13,    0,  266,    2, 0x0a /* Public */,
      14,    0,  267,    2, 0x0a /* Public */,
      15,    0,  268,    2, 0x0a /* Public */,
      16,    0,  269,    2, 0x0a /* Public */,
      17,    1,  270,    2, 0x0a /* Public */,
      19,    0,  273,    2, 0x0a /* Public */,
      20,    0,  274,    2, 0x0a /* Public */,
      21,    0,  275,    2, 0x0a /* Public */,
      22,    0,  276,    2, 0x0a /* Public */,
      23,    0,  277,    2, 0x0a /* Public */,
      24,    0,  278,    2, 0x0a /* Public */,
      25,    0,  279,    2, 0x0a /* Public */,
      26,    0,  280,    2, 0x0a /* Public */,
      27,    2,  281,    2, 0x0a /* Public */,
      28,    1,  286,    2, 0x0a /* Public */,
      29,    2,  289,    2, 0x0a /* Public */,
      30,    2,  294,    2, 0x0a /* Public */,
      31,    1,  299,    2, 0x0a /* Public */,
      32,    1,  302,    2, 0x0a /* Public */,
      33,    3,  305,    2, 0x0a /* Public */,
      34,    3,  312,    2, 0x0a /* Public */,
      35,    2,  319,    2, 0x0a /* Public */,
      35,    2,  324,    2, 0x0a /* Public */,
      37,    2,  329,    2, 0x0a /* Public */,
      39,    1,  334,    2, 0x0a /* Public */,
      40,    1,  337,    2, 0x0a /* Public */,
      41,    4,  340,    2, 0x0a /* Public */,
      42,    2,  349,    2, 0x0a /* Public */,
      43,    1,  354,    2, 0x0a /* Public */,
      44,    1,  357,    2, 0x0a /* Public */,
      45,    0,  360,    2, 0x0a /* Public */,
      46,    0,  361,    2, 0x0a /* Public */,
      47,    1,  362,    2, 0x0a /* Public */,
      48,    1,  365,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void, QMetaType::QString,    6,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QReal,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   18,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,    2,
    QMetaType::Void, 0x80000000 | 36, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 38,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Double, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Double,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage,    2,
    QMetaType::Void, QMetaType::QString,    2,

       0        // eod
};

void RunController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RunController *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->runHalted(); break;
        case 1: _t->speakWords((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 2: _t->executeSystem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->inputEntered((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 4: _t->outputReady((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->outputError((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->outputClear(); break;
        case 7: _t->outputTextAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 8: _t->goutputReady(); break;
        case 9: _t->resizeGraphWindow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 10: _t->startDebug(); break;
        case 11: _t->debugNextStep(); break;
        case 12: _t->startRun(); break;
        case 13: _t->stopRun(); break;
        case 14: _t->stopRunFinalized((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->stepThrough(); break;
        case 16: _t->stepBreakPoint(); break;
        case 17: _t->showOnlineDocumentation(); break;
        case 18: _t->showOnlineContextDocumentation(); break;
        case 19: _t->showPreferences(); break;
        case 20: _t->showReplace(); break;
        case 21: _t->showFind(); break;
        case 22: _t->findAgain(); break;
        case 23: _t->mainWindowsVisible((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 24: _t->dialogAlert((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 25: _t->dialogConfirm((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 26: _t->dialogPrompt((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 27: _t->dialogAllowPortInOut((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 28: _t->dialogAllowSystem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 29: _t->dialogOpenFileDialog((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 30: _t->dialogSaveFileDialog((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 31: _t->playSound((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 32: _t->playSound((*reinterpret_cast< std::vector<std::vector<double> >(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 33: _t->loadSoundFromArray((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QByteArray*(*)>(_a[2]))); break;
        case 34: _t->soundStop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 35: _t->soundPlay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 36: _t->soundFade((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 37: _t->soundVolume((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2]))); break;
        case 38: _t->soundPlayerOff((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 39: _t->soundSystem((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 40: _t->getClipboardImage(); break;
        case 41: _t->getClipboardString(); break;
        case 42: _t->setClipboardImage((*reinterpret_cast< QImage(*)>(_a[1]))); break;
        case 43: _t->setClipboardString((*reinterpret_cast< QString(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (RunController::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&RunController::runHalted)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject RunController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_RunController.data,
    qt_meta_data_RunController,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RunController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RunController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RunController.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RunController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void RunController::runHalted()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
