/****************************************************************************
** Meta object code from reading C++ file 'Sound.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../Sound.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Sound.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Sound_t {
    QByteArrayData data[18];
    char stringdata0[320];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Sound_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Sound_t qt_meta_stringdata_Sound = {
    {
QT_MOC_LITERAL(0, 0, 5), // "Sound"
QT_MOC_LITERAL(1, 6, 15), // "exitWaitingLoop"
QT_MOC_LITERAL(2, 22, 0), // ""
QT_MOC_LITERAL(3, 23, 8), // "deleteMe"
QT_MOC_LITERAL(4, 32, 19), // "validateLoadedSound"
QT_MOC_LITERAL(5, 52, 21), // "stopsSoundsAndWaiting"
QT_MOC_LITERAL(6, 74, 17), // "systemMassCommand"
QT_MOC_LITERAL(7, 92, 23), // "handleAudioStateChanged"
QT_MOC_LITERAL(8, 116, 13), // "QAudio::State"
QT_MOC_LITERAL(9, 130, 23), // "handleMediaStateChanged"
QT_MOC_LITERAL(10, 154, 19), // "QMediaPlayer::State"
QT_MOC_LITERAL(11, 174, 26), // "handleMediaDurationChanged"
QT_MOC_LITERAL(12, 201, 24), // "handleMediaStatusChanged"
QT_MOC_LITERAL(13, 226, 25), // "QMediaPlayer::MediaStatus"
QT_MOC_LITERAL(14, 252, 16), // "handleMediaError"
QT_MOC_LITERAL(15, 269, 19), // "QMediaPlayer::Error"
QT_MOC_LITERAL(16, 289, 21), // "handlePositionChanged"
QT_MOC_LITERAL(17, 311, 8) // "position"

    },
    "Sound\0exitWaitingLoop\0\0deleteMe\0"
    "validateLoadedSound\0stopsSoundsAndWaiting\0"
    "systemMassCommand\0handleAudioStateChanged\0"
    "QAudio::State\0handleMediaStateChanged\0"
    "QMediaPlayer::State\0handleMediaDurationChanged\0"
    "handleMediaStatusChanged\0"
    "QMediaPlayer::MediaStatus\0handleMediaError\0"
    "QMediaPlayer::Error\0handlePositionChanged\0"
    "position"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Sound[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    1,   70,    2, 0x06 /* Public */,
       4,    2,   73,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    0,   78,    2, 0x0a /* Public */,
       6,    1,   79,    2, 0x0a /* Public */,
       7,    1,   82,    2, 0x08 /* Private */,
       9,    1,   85,    2, 0x08 /* Private */,
      11,    1,   88,    2, 0x08 /* Private */,
      12,    1,   91,    2, 0x08 /* Private */,
      14,    1,   94,    2, 0x08 /* Private */,
      16,    1,   97,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void, 0x80000000 | 10,    2,
    QMetaType::Void, QMetaType::LongLong,    2,
    QMetaType::Void, 0x80000000 | 13,    2,
    QMetaType::Void, 0x80000000 | 15,    2,
    QMetaType::Void, QMetaType::LongLong,   17,

       0        // eod
};

void Sound::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Sound *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->exitWaitingLoop(); break;
        case 1: _t->deleteMe((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->validateLoadedSound((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 3: _t->stopsSoundsAndWaiting(); break;
        case 4: _t->systemMassCommand((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->handleAudioStateChanged((*reinterpret_cast< QAudio::State(*)>(_a[1]))); break;
        case 6: _t->handleMediaStateChanged((*reinterpret_cast< QMediaPlayer::State(*)>(_a[1]))); break;
        case 7: _t->handleMediaDurationChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        case 8: _t->handleMediaStatusChanged((*reinterpret_cast< QMediaPlayer::MediaStatus(*)>(_a[1]))); break;
        case 9: _t->handleMediaError((*reinterpret_cast< QMediaPlayer::Error(*)>(_a[1]))); break;
        case 10: _t->handlePositionChanged((*reinterpret_cast< qint64(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAudio::State >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::State >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::MediaStatus >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QMediaPlayer::Error >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Sound::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Sound::exitWaitingLoop)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Sound::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Sound::deleteMe)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Sound::*)(QString , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Sound::validateLoadedSound)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Sound::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Sound.data,
    qt_meta_data_Sound,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Sound::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sound::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Sound.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Sound::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void Sound::exitWaitingLoop()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Sound::deleteMe(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void Sound::validateLoadedSound(QString _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}
struct qt_meta_stringdata_SoundSystem_t {
    QByteArrayData data[6];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SoundSystem_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SoundSystem_t qt_meta_stringdata_SoundSystem = {
    {
QT_MOC_LITERAL(0, 0, 11), // "SoundSystem"
QT_MOC_LITERAL(1, 12, 21), // "stopsSoundsAndWaiting"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 17), // "systemMassCommand"
QT_MOC_LITERAL(4, 53, 8), // "deleteMe"
QT_MOC_LITERAL(5, 62, 19) // "validateLoadedSound"

    },
    "SoundSystem\0stopsSoundsAndWaiting\0\0"
    "systemMassCommand\0deleteMe\0"
    "validateLoadedSound"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SoundSystem[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   34,    2, 0x06 /* Public */,
       3,    1,   35,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,   38,    2, 0x08 /* Private */,
       5,    2,   41,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,    2,

       0        // eod
};

void SoundSystem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SoundSystem *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->stopsSoundsAndWaiting(); break;
        case 1: _t->systemMassCommand((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->deleteMe((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->validateLoadedSound((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (SoundSystem::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SoundSystem::stopsSoundsAndWaiting)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (SoundSystem::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&SoundSystem::systemMassCommand)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject SoundSystem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_SoundSystem.data,
    qt_meta_data_SoundSystem,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SoundSystem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SoundSystem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SoundSystem.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SoundSystem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SoundSystem::stopsSoundsAndWaiting()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SoundSystem::systemMassCommand(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
