/****************************************************************************
** Meta object code from reading C++ file 'PreferencesWin.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../PreferencesWin.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'PreferencesWin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_SettingsBrowser_t {
    QByteArrayData data[4];
    char stringdata0[61];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_SettingsBrowser_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_SettingsBrowser_t qt_meta_stringdata_SettingsBrowser = {
    {
QT_MOC_LITERAL(0, 0, 15), // "SettingsBrowser"
QT_MOC_LITERAL(1, 16, 25), // "treeWidgetCheckboxChanged"
QT_MOC_LITERAL(2, 42, 0), // ""
QT_MOC_LITERAL(3, 43, 17) // "clickDeleteButton"

    },
    "SettingsBrowser\0treeWidgetCheckboxChanged\0"
    "\0clickDeleteButton"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_SettingsBrowser[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   24,    2, 0x08 /* Private */,
       3,    0,   25,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void SettingsBrowser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SettingsBrowser *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->treeWidgetCheckboxChanged(); break;
        case 1: _t->clickDeleteButton(); break;
        default: ;
        }
    }
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject SettingsBrowser::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_SettingsBrowser.data,
    qt_meta_data_SettingsBrowser,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *SettingsBrowser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SettingsBrowser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_SettingsBrowser.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int SettingsBrowser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_PreferencesWin_t {
    QByteArrayData data[11];
    char stringdata0[180];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_PreferencesWin_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_PreferencesWin_t qt_meta_stringdata_PreferencesWin = {
    {
QT_MOC_LITERAL(0, 0, 14), // "PreferencesWin"
QT_MOC_LITERAL(1, 15, 17), // "clickCancelButton"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 15), // "clickSaveButton"
QT_MOC_LITERAL(4, 50, 14), // "setDigitsValue"
QT_MOC_LITERAL(5, 65, 18), // "setDebugSpeedValue"
QT_MOC_LITERAL(6, 84, 14), // "setVolumeValue"
QT_MOC_LITERAL(7, 99, 17), // "setNormalizeValue"
QT_MOC_LITERAL(8, 117, 21), // "setVolumeRestoreValue"
QT_MOC_LITERAL(9, 139, 19), // "clickClearSavedData"
QT_MOC_LITERAL(10, 159, 20) // "clickBrowseSavedData"

    },
    "PreferencesWin\0clickCancelButton\0\0"
    "clickSaveButton\0setDigitsValue\0"
    "setDebugSpeedValue\0setVolumeValue\0"
    "setNormalizeValue\0setVolumeRestoreValue\0"
    "clickClearSavedData\0clickBrowseSavedData"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_PreferencesWin[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   59,    2, 0x08 /* Private */,
       3,    0,   60,    2, 0x08 /* Private */,
       4,    1,   61,    2, 0x08 /* Private */,
       5,    1,   64,    2, 0x08 /* Private */,
       6,    1,   67,    2, 0x08 /* Private */,
       7,    1,   70,    2, 0x08 /* Private */,
       8,    1,   73,    2, 0x08 /* Private */,
       9,    0,   76,    2, 0x08 /* Private */,
      10,    0,   77,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void PreferencesWin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<PreferencesWin *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clickCancelButton(); break;
        case 1: _t->clickSaveButton(); break;
        case 2: _t->setDigitsValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 3: _t->setDebugSpeedValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->setVolumeValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 5: _t->setNormalizeValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 6: _t->setVolumeRestoreValue((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->clickClearSavedData(); break;
        case 8: _t->clickBrowseSavedData(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject PreferencesWin::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_PreferencesWin.data,
    qt_meta_data_PreferencesWin,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *PreferencesWin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PreferencesWin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_PreferencesWin.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int PreferencesWin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
