/****************************************************************************
** Meta object code from reading C++ file 'BasicEdit.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../BasicEdit.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BasicEdit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BasicEdit_t {
    QByteArrayData data[33];
    char stringdata0[508];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BasicEdit_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BasicEdit_t qt_meta_stringdata_BasicEdit = {
    {
QT_MOC_LITERAL(0, 0, 9), // "BasicEdit"
QT_MOC_LITERAL(1, 10, 15), // "changeStatusBar"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 17), // "updateWindowTitle"
QT_MOC_LITERAL(4, 45, 10), // "BasicEdit*"
QT_MOC_LITERAL(5, 56, 19), // "addFileToRecentList"
QT_MOC_LITERAL(6, 76, 19), // "updateEditorButtons"
QT_MOC_LITERAL(7, 96, 19), // "setCurrentEditorTab"
QT_MOC_LITERAL(8, 116, 11), // "saveProgram"
QT_MOC_LITERAL(9, 128, 11), // "saveAllStep"
QT_MOC_LITERAL(10, 140, 13), // "saveAsProgram"
QT_MOC_LITERAL(11, 154, 10), // "cursorMove"
QT_MOC_LITERAL(12, 165, 8), // "goToLine"
QT_MOC_LITERAL(13, 174, 8), // "seekLine"
QT_MOC_LITERAL(14, 183, 9), // "slotPrint"
QT_MOC_LITERAL(15, 193, 15), // "beautifyProgram"
QT_MOC_LITERAL(16, 209, 14), // "slotWhitespace"
QT_MOC_LITERAL(17, 224, 8), // "slotWrap"
QT_MOC_LITERAL(18, 233, 20), // "highlightCurrentLine"
QT_MOC_LITERAL(19, 254, 15), // "indentSelection"
QT_MOC_LITERAL(20, 270, 17), // "unindentSelection"
QT_MOC_LITERAL(21, 288, 16), // "clearBreakPoints"
QT_MOC_LITERAL(22, 305, 16), // "toggleBreakPoint"
QT_MOC_LITERAL(23, 322, 11), // "updateTitle"
QT_MOC_LITERAL(24, 334, 17), // "setEditorRunState"
QT_MOC_LITERAL(25, 352, 21), // "fileChangedOnDiskSlot"
QT_MOC_LITERAL(26, 374, 25), // "updateLineNumberAreaWidth"
QT_MOC_LITERAL(27, 400, 13), // "newBlockCount"
QT_MOC_LITERAL(28, 414, 20), // "updateLineNumberArea"
QT_MOC_LITERAL(29, 435, 17), // "slotUndoAvailable"
QT_MOC_LITERAL(30, 453, 17), // "slotRedoAvailable"
QT_MOC_LITERAL(31, 471, 17), // "slotCopyAvailable"
QT_MOC_LITERAL(32, 489, 18) // "actionWasTriggered"

    },
    "BasicEdit\0changeStatusBar\0\0updateWindowTitle\0"
    "BasicEdit*\0addFileToRecentList\0"
    "updateEditorButtons\0setCurrentEditorTab\0"
    "saveProgram\0saveAllStep\0saveAsProgram\0"
    "cursorMove\0goToLine\0seekLine\0slotPrint\0"
    "beautifyProgram\0slotWhitespace\0slotWrap\0"
    "highlightCurrentLine\0indentSelection\0"
    "unindentSelection\0clearBreakPoints\0"
    "toggleBreakPoint\0updateTitle\0"
    "setEditorRunState\0fileChangedOnDiskSlot\0"
    "updateLineNumberAreaWidth\0newBlockCount\0"
    "updateLineNumberArea\0slotUndoAvailable\0"
    "slotRedoAvailable\0slotCopyAvailable\0"
    "actionWasTriggered"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BasicEdit[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      29,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       5,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  159,    2, 0x06 /* Public */,
       3,    1,  162,    2, 0x06 /* Public */,
       5,    1,  165,    2, 0x06 /* Public */,
       6,    0,  168,    2, 0x06 /* Public */,
       7,    1,  169,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    0,  172,    2, 0x0a /* Public */,
       9,    1,  173,    2, 0x0a /* Public */,
      10,    0,  176,    2, 0x0a /* Public */,
      11,    0,  177,    2, 0x0a /* Public */,
      12,    1,  178,    2, 0x0a /* Public */,
      13,    1,  181,    2, 0x0a /* Public */,
      14,    0,  184,    2, 0x0a /* Public */,
      15,    0,  185,    2, 0x0a /* Public */,
      16,    1,  186,    2, 0x0a /* Public */,
      17,    1,  189,    2, 0x0a /* Public */,
      18,    0,  192,    2, 0x0a /* Public */,
      19,    0,  193,    2, 0x0a /* Public */,
      20,    0,  194,    2, 0x0a /* Public */,
      21,    0,  195,    2, 0x0a /* Public */,
      22,    0,  196,    2, 0x0a /* Public */,
      23,    0,  197,    2, 0x0a /* Public */,
      24,    1,  198,    2, 0x0a /* Public */,
      25,    1,  201,    2, 0x0a /* Public */,
      26,    1,  204,    2, 0x08 /* Private */,
      28,    2,  207,    2, 0x08 /* Private */,
      29,    1,  212,    2, 0x08 /* Private */,
      30,    1,  215,    2, 0x08 /* Private */,
      31,    1,  218,    2, 0x08 /* Private */,
      32,    0,  221,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 4,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Int,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,   27,
    QMetaType::Void, QMetaType::QRect, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,

       0        // eod
};

void BasicEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BasicEdit *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->changeStatusBar((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->updateWindowTitle((*reinterpret_cast< BasicEdit*(*)>(_a[1]))); break;
        case 2: _t->addFileToRecentList((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->updateEditorButtons(); break;
        case 4: _t->setCurrentEditorTab((*reinterpret_cast< BasicEdit*(*)>(_a[1]))); break;
        case 5: _t->saveProgram(); break;
        case 6: _t->saveAllStep((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->saveAsProgram(); break;
        case 8: _t->cursorMove(); break;
        case 9: _t->goToLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->seekLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 11: _t->slotPrint(); break;
        case 12: _t->beautifyProgram(); break;
        case 13: _t->slotWhitespace((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->slotWrap((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 15: _t->highlightCurrentLine(); break;
        case 16: { int _r = _t->indentSelection();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->unindentSelection(); break;
        case 18: _t->clearBreakPoints(); break;
        case 19: _t->toggleBreakPoint(); break;
        case 20: _t->updateTitle(); break;
        case 21: _t->setEditorRunState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 22: _t->fileChangedOnDiskSlot((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 23: _t->updateLineNumberAreaWidth((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->updateLineNumberArea((*reinterpret_cast< const QRect(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 25: _t->slotUndoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 26: _t->slotRedoAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 27: _t->slotCopyAvailable((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 28: _t->actionWasTriggered(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BasicEdit* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BasicEdit* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BasicEdit::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicEdit::changeStatusBar)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BasicEdit::*)(BasicEdit * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicEdit::updateWindowTitle)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (BasicEdit::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicEdit::addFileToRecentList)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (BasicEdit::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicEdit::updateEditorButtons)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (BasicEdit::*)(BasicEdit * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicEdit::setCurrentEditorTab)) {
                *result = 4;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BasicEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QPlainTextEdit::staticMetaObject>(),
    qt_meta_stringdata_BasicEdit.data,
    qt_meta_data_BasicEdit,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BasicEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BasicEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BasicEdit.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ViewWidgetIFace"))
        return static_cast< ViewWidgetIFace*>(this);
    return QPlainTextEdit::qt_metacast(_clname);
}

int BasicEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPlainTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 29)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 29;
    }
    return _id;
}

// SIGNAL 0
void BasicEdit::changeStatusBar(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BasicEdit::updateWindowTitle(BasicEdit * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void BasicEdit::addFileToRecentList(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void BasicEdit::updateEditorButtons()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void BasicEdit::setCurrentEditorTab(BasicEdit * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
