/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../MainWindow.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_MainWindow_t {
    QByteArrayData data[41];
    char stringdata0[678];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_MainWindow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_MainWindow_t qt_meta_stringdata_MainWindow = {
    {
QT_MOC_LITERAL(0, 0, 10), // "MainWindow"
QT_MOC_LITERAL(1, 11, 17), // "setEditorRunState"
QT_MOC_LITERAL(2, 29, 0), // ""
QT_MOC_LITERAL(3, 30, 11), // "saveAllStep"
QT_MOC_LITERAL(4, 42, 15), // "updateStatusBar"
QT_MOC_LITERAL(5, 58, 17), // "updateWindowTitle"
QT_MOC_LITERAL(6, 76, 10), // "BasicEdit*"
QT_MOC_LITERAL(7, 87, 10), // "newProgram"
QT_MOC_LITERAL(8, 98, 19), // "updateEditorButtons"
QT_MOC_LITERAL(9, 118, 14), // "checkForUpdate"
QT_MOC_LITERAL(10, 133, 12), // "updateRecent"
QT_MOC_LITERAL(11, 146, 16), // "updateWindowMenu"
QT_MOC_LITERAL(12, 163, 11), // "emptyRecent"
QT_MOC_LITERAL(13, 175, 19), // "addFileToRecentList"
QT_MOC_LITERAL(14, 195, 5), // "about"
QT_MOC_LITERAL(15, 201, 10), // "openRecent"
QT_MOC_LITERAL(16, 212, 16), // "dialogFontSelect"
QT_MOC_LITERAL(17, 229, 17), // "activeEditorPrint"
QT_MOC_LITERAL(18, 247, 23), // "activeEditorSaveProgram"
QT_MOC_LITERAL(19, 271, 25), // "activeEditorSaveAsProgram"
QT_MOC_LITERAL(20, 297, 16), // "activeEditorUndo"
QT_MOC_LITERAL(21, 314, 16), // "activeEditorRedo"
QT_MOC_LITERAL(22, 331, 15), // "activeEditorCut"
QT_MOC_LITERAL(23, 347, 16), // "activeEditorCopy"
QT_MOC_LITERAL(24, 364, 17), // "activeEditorPaste"
QT_MOC_LITERAL(25, 382, 21), // "activeEditorSelectAll"
QT_MOC_LITERAL(26, 404, 27), // "activeEditorBeautifyProgram"
QT_MOC_LITERAL(27, 432, 28), // "activeEditorClearBreakPoints"
QT_MOC_LITERAL(28, 461, 23), // "currentEditorTabChanged"
QT_MOC_LITERAL(29, 485, 14), // "closeEditorTab"
QT_MOC_LITERAL(30, 500, 11), // "loadProgram"
QT_MOC_LITERAL(31, 512, 20), // "activeEditorCloseTab"
QT_MOC_LITERAL(32, 533, 16), // "closeAllPrograms"
QT_MOC_LITERAL(33, 550, 19), // "setCurrentEditorTab"
QT_MOC_LITERAL(34, 570, 7), // "saveAll"
QT_MOC_LITERAL(35, 578, 23), // "updateBreakPointsAction"
QT_MOC_LITERAL(36, 602, 20), // "zoomGroupActionEvent"
QT_MOC_LITERAL(37, 623, 8), // "QAction*"
QT_MOC_LITERAL(38, 632, 24), // "sourceforgeReplyFinished"
QT_MOC_LITERAL(39, 657, 14), // "QNetworkReply*"
QT_MOC_LITERAL(40, 672, 5) // "reply"

    },
    "MainWindow\0setEditorRunState\0\0saveAllStep\0"
    "updateStatusBar\0updateWindowTitle\0"
    "BasicEdit*\0newProgram\0updateEditorButtons\0"
    "checkForUpdate\0updateRecent\0"
    "updateWindowMenu\0emptyRecent\0"
    "addFileToRecentList\0about\0openRecent\0"
    "dialogFontSelect\0activeEditorPrint\0"
    "activeEditorSaveProgram\0"
    "activeEditorSaveAsProgram\0activeEditorUndo\0"
    "activeEditorRedo\0activeEditorCut\0"
    "activeEditorCopy\0activeEditorPaste\0"
    "activeEditorSelectAll\0activeEditorBeautifyProgram\0"
    "activeEditorClearBreakPoints\0"
    "currentEditorTabChanged\0closeEditorTab\0"
    "loadProgram\0activeEditorCloseTab\0"
    "closeAllPrograms\0setCurrentEditorTab\0"
    "saveAll\0updateBreakPointsAction\0"
    "zoomGroupActionEvent\0QAction*\0"
    "sourceforgeReplyFinished\0QNetworkReply*\0"
    "reply"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_MainWindow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,  189,    2, 0x06 /* Public */,
       3,    1,  192,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    1,  195,    2, 0x0a /* Public */,
       5,    1,  198,    2, 0x0a /* Public */,
       7,    0,  201,    2, 0x0a /* Public */,
       8,    0,  202,    2, 0x0a /* Public */,
       9,    0,  203,    2, 0x0a /* Public */,
      10,    0,  204,    2, 0x08 /* Private */,
      11,    0,  205,    2, 0x08 /* Private */,
      12,    0,  206,    2, 0x08 /* Private */,
      13,    1,  207,    2, 0x08 /* Private */,
      14,    0,  210,    2, 0x08 /* Private */,
      15,    0,  211,    2, 0x08 /* Private */,
      16,    0,  212,    2, 0x08 /* Private */,
      17,    0,  213,    2, 0x08 /* Private */,
      18,    0,  214,    2, 0x08 /* Private */,
      19,    0,  215,    2, 0x08 /* Private */,
      20,    0,  216,    2, 0x08 /* Private */,
      21,    0,  217,    2, 0x08 /* Private */,
      22,    0,  218,    2, 0x08 /* Private */,
      23,    0,  219,    2, 0x08 /* Private */,
      24,    0,  220,    2, 0x08 /* Private */,
      25,    0,  221,    2, 0x08 /* Private */,
      26,    0,  222,    2, 0x08 /* Private */,
      27,    0,  223,    2, 0x08 /* Private */,
      28,    1,  224,    2, 0x08 /* Private */,
      29,    1,  227,    2, 0x08 /* Private */,
      30,    0,  230,    2, 0x08 /* Private */,
      31,    0,  231,    2, 0x08 /* Private */,
      32,    0,  232,    2, 0x08 /* Private */,
      33,    1,  233,    2, 0x08 /* Private */,
      34,    0,  236,    2, 0x08 /* Private */,
      35,    0,  237,    2, 0x08 /* Private */,
      36,    1,  238,    2, 0x08 /* Private */,
      38,    1,  241,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Bool,
    QMetaType::Void, 0x80000000 | 6,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 37,    2,
    QMetaType::Void, 0x80000000 | 39,   40,

       0        // eod
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<MainWindow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->setEditorRunState((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->saveAllStep((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->updateStatusBar((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 3: _t->updateWindowTitle((*reinterpret_cast< BasicEdit*(*)>(_a[1]))); break;
        case 4: _t->newProgram(); break;
        case 5: _t->updateEditorButtons(); break;
        case 6: _t->checkForUpdate(); break;
        case 7: _t->updateRecent(); break;
        case 8: _t->updateWindowMenu(); break;
        case 9: _t->emptyRecent(); break;
        case 10: _t->addFileToRecentList((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->about(); break;
        case 12: _t->openRecent(); break;
        case 13: _t->dialogFontSelect(); break;
        case 14: _t->activeEditorPrint(); break;
        case 15: _t->activeEditorSaveProgram(); break;
        case 16: _t->activeEditorSaveAsProgram(); break;
        case 17: _t->activeEditorUndo(); break;
        case 18: _t->activeEditorRedo(); break;
        case 19: _t->activeEditorCut(); break;
        case 20: _t->activeEditorCopy(); break;
        case 21: _t->activeEditorPaste(); break;
        case 22: _t->activeEditorSelectAll(); break;
        case 23: _t->activeEditorBeautifyProgram(); break;
        case 24: _t->activeEditorClearBreakPoints(); break;
        case 25: _t->currentEditorTabChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->closeEditorTab((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 27: _t->loadProgram(); break;
        case 28: _t->activeEditorCloseTab(); break;
        case 29: { bool _r = _t->closeAllPrograms();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 30: _t->setCurrentEditorTab((*reinterpret_cast< BasicEdit*(*)>(_a[1]))); break;
        case 31: _t->saveAll(); break;
        case 32: _t->updateBreakPointsAction(); break;
        case 33: _t->zoomGroupActionEvent((*reinterpret_cast< QAction*(*)>(_a[1]))); break;
        case 34: _t->sourceforgeReplyFinished((*reinterpret_cast< QNetworkReply*(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BasicEdit* >(); break;
            }
            break;
        case 30:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< BasicEdit* >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAction* >(); break;
            }
            break;
        case 34:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QNetworkReply* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (MainWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::setEditorRunState)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (MainWindow::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&MainWindow::saveAllStep)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_meta_stringdata_MainWindow.data,
    qt_meta_data_MainWindow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow.stringdata0))
        return static_cast<void*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::setEditorRunState(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void MainWindow::saveAllStep(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
