/****************************************************************************
** Meta object code from reading C++ file 'Interpreter.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../Interpreter.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Interpreter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Interpreter_t {
    QByteArrayData data[47];
    char stringdata0[644];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Interpreter_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Interpreter_t qt_meta_stringdata_Interpreter = {
    {
QT_MOC_LITERAL(0, 0, 11), // "Interpreter"
QT_MOC_LITERAL(1, 12, 13), // "debugNextStep"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 12), // "fastGraphics"
QT_MOC_LITERAL(4, 40, 16), // "stopRunFinalized"
QT_MOC_LITERAL(5, 57, 12), // "goutputReady"
QT_MOC_LITERAL(6, 70, 11), // "outputReady"
QT_MOC_LITERAL(7, 82, 11), // "outputError"
QT_MOC_LITERAL(8, 94, 12), // "outputTextAt"
QT_MOC_LITERAL(9, 107, 8), // "getInput"
QT_MOC_LITERAL(10, 116, 11), // "outputClear"
QT_MOC_LITERAL(11, 128, 6), // "getKey"
QT_MOC_LITERAL(12, 135, 10), // "playSounds"
QT_MOC_LITERAL(13, 146, 4), // "int*"
QT_MOC_LITERAL(14, 151, 9), // "setVolume"
QT_MOC_LITERAL(15, 161, 10), // "speakWords"
QT_MOC_LITERAL(16, 172, 8), // "goToLine"
QT_MOC_LITERAL(17, 181, 8), // "seekLine"
QT_MOC_LITERAL(18, 190, 12), // "varWinAssign"
QT_MOC_LITERAL(19, 203, 11), // "Variables**"
QT_MOC_LITERAL(20, 215, 15), // "varWinDropLevel"
QT_MOC_LITERAL(21, 231, 14), // "varWinDimArray"
QT_MOC_LITERAL(22, 246, 17), // "resizeGraphWindow"
QT_MOC_LITERAL(23, 264, 18), // "mainWindowsVisible"
QT_MOC_LITERAL(24, 283, 11), // "dialogAlert"
QT_MOC_LITERAL(25, 295, 13), // "dialogConfirm"
QT_MOC_LITERAL(26, 309, 12), // "dialogPrompt"
QT_MOC_LITERAL(27, 322, 20), // "dialogOpenFileDialog"
QT_MOC_LITERAL(28, 343, 20), // "dialogSaveFileDialog"
QT_MOC_LITERAL(29, 364, 20), // "dialogAllowPortInOut"
QT_MOC_LITERAL(30, 385, 17), // "dialogAllowSystem"
QT_MOC_LITERAL(31, 403, 9), // "playSound"
QT_MOC_LITERAL(32, 413, 33), // "std::vector<std::vector<doubl..."
QT_MOC_LITERAL(33, 447, 18), // "loadSoundFromArray"
QT_MOC_LITERAL(34, 466, 11), // "QByteArray*"
QT_MOC_LITERAL(35, 478, 9), // "soundStop"
QT_MOC_LITERAL(36, 488, 9), // "soundPlay"
QT_MOC_LITERAL(37, 498, 9), // "soundFade"
QT_MOC_LITERAL(38, 508, 11), // "soundVolume"
QT_MOC_LITERAL(39, 520, 14), // "soundPlayerOff"
QT_MOC_LITERAL(40, 535, 11), // "soundSystem"
QT_MOC_LITERAL(41, 547, 17), // "getClipboardImage"
QT_MOC_LITERAL(42, 565, 18), // "getClipboardString"
QT_MOC_LITERAL(43, 584, 17), // "setClipboardImage"
QT_MOC_LITERAL(44, 602, 18), // "setClipboardString"
QT_MOC_LITERAL(45, 621, 12), // "execByteCode"
QT_MOC_LITERAL(46, 634, 9) // "runHalted"

    },
    "Interpreter\0debugNextStep\0\0fastGraphics\0"
    "stopRunFinalized\0goutputReady\0outputReady\0"
    "outputError\0outputTextAt\0getInput\0"
    "outputClear\0getKey\0playSounds\0int*\0"
    "setVolume\0speakWords\0goToLine\0seekLine\0"
    "varWinAssign\0Variables**\0varWinDropLevel\0"
    "varWinDimArray\0resizeGraphWindow\0"
    "mainWindowsVisible\0dialogAlert\0"
    "dialogConfirm\0dialogPrompt\0"
    "dialogOpenFileDialog\0dialogSaveFileDialog\0"
    "dialogAllowPortInOut\0dialogAllowSystem\0"
    "playSound\0std::vector<std::vector<double> >\0"
    "loadSoundFromArray\0QByteArray*\0soundStop\0"
    "soundPlay\0soundFade\0soundVolume\0"
    "soundPlayerOff\0soundSystem\0getClipboardImage\0"
    "getClipboardString\0setClipboardImage\0"
    "setClipboardString\0execByteCode\0"
    "runHalted"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Interpreter[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      42,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  234,    2, 0x06 /* Public */,
       3,    0,  235,    2, 0x06 /* Public */,
       4,    1,  236,    2, 0x06 /* Public */,
       5,    0,  239,    2, 0x06 /* Public */,
       6,    1,  240,    2, 0x06 /* Public */,
       7,    1,  243,    2, 0x06 /* Public */,
       8,    3,  246,    2, 0x06 /* Public */,
       9,    0,  253,    2, 0x06 /* Public */,
      10,    0,  254,    2, 0x06 /* Public */,
      11,    0,  255,    2, 0x06 /* Public */,
      12,    2,  256,    2, 0x06 /* Public */,
      14,    1,  261,    2, 0x06 /* Public */,
      15,    1,  264,    2, 0x06 /* Public */,
      16,    1,  267,    2, 0x06 /* Public */,
      17,    1,  270,    2, 0x06 /* Public */,
      18,    3,  273,    2, 0x06 /* Public */,
      18,    5,  280,    2, 0x06 /* Public */,
      18,    4,  291,    2, 0x06 /* Public */,
      20,    1,  300,    2, 0x06 /* Public */,
      21,    4,  303,    2, 0x06 /* Public */,
      22,    3,  312,    2, 0x06 /* Public */,
      23,    2,  319,    2, 0x06 /* Public */,
      24,    1,  324,    2, 0x06 /* Public */,
      25,    2,  327,    2, 0x06 /* Public */,
      26,    2,  332,    2, 0x06 /* Public */,
      27,    3,  337,    2, 0x06 /* Public */,
      28,    3,  344,    2, 0x06 /* Public */,
      29,    1,  351,    2, 0x06 /* Public */,
      30,    1,  354,    2, 0x06 /* Public */,
      31,    2,  357,    2, 0x06 /* Public */,
      31,    2,  362,    2, 0x06 /* Public */,
      33,    2,  367,    2, 0x06 /* Public */,
      35,    1,  372,    2, 0x06 /* Public */,
      36,    1,  375,    2, 0x06 /* Public */,
      37,    4,  378,    2, 0x06 /* Public */,
      38,    2,  387,    2, 0x06 /* Public */,
      39,    1,  392,    2, 0x06 /* Public */,
      40,    1,  395,    2, 0x06 /* Public */,
      41,    0,  398,    2, 0x06 /* Public */,
      42,    0,  399,    2, 0x06 /* Public */,
      43,    1,  400,    2, 0x06 /* Public */,
      44,    1,  403,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      45,    0,  406,    2, 0x0a /* Public */,
      46,    0,  407,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QString,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int, 0x80000000 | 13,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 19, QMetaType::Int, QMetaType::Int,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 19, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,    2,
    QMetaType::Void, 0x80000000 | 19, QMetaType::Int, QMetaType::Int, QMetaType::QString,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, 0x80000000 | 19, QMetaType::Int, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QReal,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString,    2,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::Bool,    2,    2,
    QMetaType::Void, 0x80000000 | 32, QMetaType::Bool,    2,    2,
    QMetaType::Void, QMetaType::QString, 0x80000000 | 34,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Double, QMetaType::Int, QMetaType::Int,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Double,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QImage,    2,
    QMetaType::Void, QMetaType::QString,    2,

 // slots: parameters
    QMetaType::Int,
    QMetaType::Void,

       0        // eod
};

void Interpreter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Interpreter *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->debugNextStep(); break;
        case 1: _t->fastGraphics(); break;
        case 2: _t->stopRunFinalized((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 3: _t->goutputReady(); break;
        case 4: _t->outputReady((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->outputError((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 6: _t->outputTextAt((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 7: _t->getInput(); break;
        case 8: _t->outputClear(); break;
        case 9: _t->getKey(); break;
        case 10: _t->playSounds((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int*(*)>(_a[2]))); break;
        case 11: _t->setVolume((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 12: _t->speakWords((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 13: _t->goToLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->seekLine((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->varWinAssign((*reinterpret_cast< Variables**(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 16: _t->varWinAssign((*reinterpret_cast< Variables**(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< int(*)>(_a[5]))); break;
        case 17: _t->varWinAssign((*reinterpret_cast< Variables**(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< QString(*)>(_a[4]))); break;
        case 18: _t->varWinDropLevel((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 19: _t->varWinDimArray((*reinterpret_cast< Variables**(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 20: _t->resizeGraphWindow((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 21: _t->mainWindowsVisible((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 22: _t->dialogAlert((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 23: _t->dialogConfirm((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 24: _t->dialogPrompt((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2]))); break;
        case 25: _t->dialogOpenFileDialog((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 26: _t->dialogSaveFileDialog((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QString(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 27: _t->dialogAllowPortInOut((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 28: _t->dialogAllowSystem((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 29: _t->playSound((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 30: _t->playSound((*reinterpret_cast< std::vector<std::vector<double> >(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 31: _t->loadSoundFromArray((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< QByteArray*(*)>(_a[2]))); break;
        case 32: _t->soundStop((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 33: _t->soundPlay((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 34: _t->soundFade((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 35: _t->soundVolume((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< double(*)>(_a[2]))); break;
        case 36: _t->soundPlayerOff((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 37: _t->soundSystem((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 38: _t->getClipboardImage(); break;
        case 39: _t->getClipboardString(); break;
        case 40: _t->setClipboardImage((*reinterpret_cast< QImage(*)>(_a[1]))); break;
        case 41: _t->setClipboardString((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 42: { int _r = _t->execByteCode();
            if (_a[0]) *reinterpret_cast< int*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->runHalted(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::debugNextStep)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::fastGraphics)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::stopRunFinalized)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::goutputReady)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::outputReady)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::outputError)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , int , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::outputTextAt)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::getInput)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::outputClear)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::getKey)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , int * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::playSounds)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::setVolume)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::speakWords)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::goToLine)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::seekLine)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(Variables * * , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::varWinAssign)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(Variables * * , int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::varWinAssign)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(Variables * * , int , int , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::varWinAssign)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::varWinDropLevel)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(Variables * * , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::varWinDimArray)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , int , qreal );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::resizeGraphWindow)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::mainWindowsVisible)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogAlert)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogConfirm)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogPrompt)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , QString , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogOpenFileDialog)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , QString , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogSaveFileDialog)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogAllowPortInOut)) {
                *result = 27;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::dialogAllowSystem)) {
                *result = 28;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::playSound)) {
                *result = 29;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(std::vector<std::vector<double>> , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::playSound)) {
                *result = 30;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString , QByteArray * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::loadSoundFromArray)) {
                *result = 31;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundStop)) {
                *result = 32;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundPlay)) {
                *result = 33;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , double , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundFade)) {
                *result = 34;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int , double );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundVolume)) {
                *result = 35;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundPlayerOff)) {
                *result = 36;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::soundSystem)) {
                *result = 37;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::getClipboardImage)) {
                *result = 38;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::getClipboardString)) {
                *result = 39;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QImage );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::setClipboardImage)) {
                *result = 40;
                return;
            }
        }
        {
            using _t = void (Interpreter::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Interpreter::setClipboardString)) {
                *result = 41;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Interpreter::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_meta_stringdata_Interpreter.data,
    qt_meta_data_Interpreter,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Interpreter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Interpreter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Interpreter.stringdata0))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int Interpreter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void Interpreter::debugNextStep()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Interpreter::fastGraphics()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Interpreter::stopRunFinalized(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void Interpreter::goutputReady()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Interpreter::outputReady(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void Interpreter::outputError(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void Interpreter::outputTextAt(int _t1, int _t2, QString _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void Interpreter::getInput()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Interpreter::outputClear()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Interpreter::getKey()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Interpreter::playSounds(int _t1, int * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 10, _a);
}

// SIGNAL 11
void Interpreter::setVolume(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 11, _a);
}

// SIGNAL 12
void Interpreter::speakWords(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 12, _a);
}

// SIGNAL 13
void Interpreter::goToLine(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 13, _a);
}

// SIGNAL 14
void Interpreter::seekLine(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 14, _a);
}

// SIGNAL 15
void Interpreter::varWinAssign(Variables * * _t1, int _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 15, _a);
}

// SIGNAL 16
void Interpreter::varWinAssign(Variables * * _t1, int _t2, int _t3, int _t4, int _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 16, _a);
}

// SIGNAL 17
void Interpreter::varWinAssign(Variables * * _t1, int _t2, int _t3, QString _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 17, _a);
}

// SIGNAL 18
void Interpreter::varWinDropLevel(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 18, _a);
}

// SIGNAL 19
void Interpreter::varWinDimArray(Variables * * _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 19, _a);
}

// SIGNAL 20
void Interpreter::resizeGraphWindow(int _t1, int _t2, qreal _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 20, _a);
}

// SIGNAL 21
void Interpreter::mainWindowsVisible(int _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 21, _a);
}

// SIGNAL 22
void Interpreter::dialogAlert(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 22, _a);
}

// SIGNAL 23
void Interpreter::dialogConfirm(QString _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 23, _a);
}

// SIGNAL 24
void Interpreter::dialogPrompt(QString _t1, QString _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 24, _a);
}

// SIGNAL 25
void Interpreter::dialogOpenFileDialog(QString _t1, QString _t2, QString _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 25, _a);
}

// SIGNAL 26
void Interpreter::dialogSaveFileDialog(QString _t1, QString _t2, QString _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 26, _a);
}

// SIGNAL 27
void Interpreter::dialogAllowPortInOut(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 27, _a);
}

// SIGNAL 28
void Interpreter::dialogAllowSystem(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 28, _a);
}

// SIGNAL 29
void Interpreter::playSound(QString _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 29, _a);
}

// SIGNAL 30
void Interpreter::playSound(std::vector<std::vector<double>> _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 30, _a);
}

// SIGNAL 31
void Interpreter::loadSoundFromArray(QString _t1, QByteArray * _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 31, _a);
}

// SIGNAL 32
void Interpreter::soundStop(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 32, _a);
}

// SIGNAL 33
void Interpreter::soundPlay(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 33, _a);
}

// SIGNAL 34
void Interpreter::soundFade(int _t1, double _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))) };
    QMetaObject::activate(this, &staticMetaObject, 34, _a);
}

// SIGNAL 35
void Interpreter::soundVolume(int _t1, double _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 35, _a);
}

// SIGNAL 36
void Interpreter::soundPlayerOff(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 36, _a);
}

// SIGNAL 37
void Interpreter::soundSystem(int _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 37, _a);
}

// SIGNAL 38
void Interpreter::getClipboardImage()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void Interpreter::getClipboardString()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void Interpreter::setClipboardImage(QImage _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 40, _a);
}

// SIGNAL 41
void Interpreter::setClipboardString(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 41, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
