/****************************************************************************
** Meta object code from reading C++ file 'BasicGraph.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../BasicGraph.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BasicGraph.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BasicGraph_t {
    QByteArrayData data[9];
    char stringdata0[82];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BasicGraph_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BasicGraph_t qt_meta_stringdata_BasicGraph = {
    {
QT_MOC_LITERAL(0, 0, 10), // "BasicGraph"
QT_MOC_LITERAL(1, 11, 6), // "resize"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 13), // "slotGridLines"
QT_MOC_LITERAL(4, 33, 8), // "slotCopy"
QT_MOC_LITERAL(5, 42, 9), // "slotPrint"
QT_MOC_LITERAL(6, 52, 9), // "slotClear"
QT_MOC_LITERAL(7, 62, 11), // "slotSetZoom"
QT_MOC_LITERAL(8, 74, 7) // "getZoom"

    },
    "BasicGraph\0resize\0\0slotGridLines\0"
    "slotCopy\0slotPrint\0slotClear\0slotSetZoom\0"
    "getZoom"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BasicGraph[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    3,   49,    2, 0x0a /* Public */,
       3,    1,   56,    2, 0x0a /* Public */,
       4,    0,   59,    2, 0x0a /* Public */,
       5,    0,   60,    2, 0x0a /* Public */,
       6,    0,   61,    2, 0x0a /* Public */,
       7,    1,   62,    2, 0x0a /* Public */,
       8,    0,   65,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::QReal,    2,    2,    2,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Double,    2,
    QMetaType::Double,

       0        // eod
};

void BasicGraph::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BasicGraph *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->resize((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< qreal(*)>(_a[3]))); break;
        case 1: _t->slotGridLines((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 2: _t->slotCopy(); break;
        case 3: _t->slotPrint(); break;
        case 4: _t->slotClear(); break;
        case 5: _t->slotSetZoom((*reinterpret_cast< double(*)>(_a[1]))); break;
        case 6: { double _r = _t->getZoom();
            if (_a[0]) *reinterpret_cast< double*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BasicGraph::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_meta_stringdata_BasicGraph.data,
    qt_meta_data_BasicGraph,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BasicGraph::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BasicGraph::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BasicGraph.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ViewWidgetIFace"))
        return static_cast< ViewWidgetIFace*>(this);
    return QWidget::qt_metacast(_clname);
}

int BasicGraph::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
