/****************************************************************************
** Meta object code from reading C++ file 'BasicOutput.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../BasicOutput.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'BasicOutput.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_BasicOutput_t {
    QByteArrayData data[12];
    char stringdata0[135];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_BasicOutput_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_BasicOutput_t qt_meta_stringdata_BasicOutput = {
    {
QT_MOC_LITERAL(0, 0, 11), // "BasicOutput"
QT_MOC_LITERAL(1, 12, 12), // "inputEntered"
QT_MOC_LITERAL(2, 25, 0), // ""
QT_MOC_LITERAL(3, 26, 18), // "mainWindowsVisible"
QT_MOC_LITERAL(4, 45, 8), // "getInput"
QT_MOC_LITERAL(5, 54, 9), // "stopInput"
QT_MOC_LITERAL(6, 64, 9), // "slotPrint"
QT_MOC_LITERAL(7, 74, 10), // "paintEvent"
QT_MOC_LITERAL(8, 85, 12), // "QPaintEvent*"
QT_MOC_LITERAL(9, 98, 17), // "updatePasteButton"
QT_MOC_LITERAL(10, 116, 9), // "slotClear"
QT_MOC_LITERAL(11, 126, 8) // "slotWrap"

    },
    "BasicOutput\0inputEntered\0\0mainWindowsVisible\0"
    "getInput\0stopInput\0slotPrint\0paintEvent\0"
    "QPaintEvent*\0updatePasteButton\0slotClear\0"
    "slotWrap"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_BasicOutput[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       9,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   59,    2, 0x06 /* Public */,
       3,    2,   62,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   67,    2, 0x0a /* Public */,
       5,    0,   68,    2, 0x0a /* Public */,
       6,    0,   69,    2, 0x0a /* Public */,
       7,    1,   70,    2, 0x0a /* Public */,
       9,    0,   73,    2, 0x0a /* Public */,
      10,    0,   74,    2, 0x0a /* Public */,
      11,    1,   75,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int, QMetaType::Bool,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 8,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void BasicOutput::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<BasicOutput *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->inputEntered((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 1: _t->mainWindowsVisible((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2]))); break;
        case 2: _t->getInput(); break;
        case 3: _t->stopInput(); break;
        case 4: _t->slotPrint(); break;
        case 5: _t->paintEvent((*reinterpret_cast< QPaintEvent*(*)>(_a[1]))); break;
        case 6: _t->updatePasteButton(); break;
        case 7: _t->slotClear(); break;
        case 8: _t->slotWrap((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (BasicOutput::*)(QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicOutput::inputEntered)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (BasicOutput::*)(int , bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&BasicOutput::mainWindowsVisible)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject BasicOutput::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextEdit::staticMetaObject>(),
    qt_meta_stringdata_BasicOutput.data,
    qt_meta_data_BasicOutput,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *BasicOutput::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BasicOutput::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_BasicOutput.stringdata0))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ViewWidgetIFace"))
        return static_cast< ViewWidgetIFace*>(this);
    return QTextEdit::qt_metacast(_clname);
}

int BasicOutput::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void BasicOutput::inputEntered(QString _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void BasicOutput::mainWindowsVisible(int _t1, bool _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
